.. _simplify-docs:

========
Simplify
========

.. currentmodule:: sympy.simplify.simplify

.. autofunction:: simplify

.. autofunction:: separatevars

.. autofunction:: nthroot

.. autofunction:: kroneckersimp

.. autofunction:: besselsimp

.. autofunction:: hypersimp

.. autofunction:: hypersimilar

.. autofunction:: nsimplify

.. autofunction:: posify

.. autofunction:: logcombine

.. module:: sympy.simplify.radsimp

.. autofunction:: radsimp

.. autofunction:: rad_rationalize

.. autofunction:: collect

.. autofunction:: rcollect

.. autofunction:: collect_sqrt

.. autofunction:: collect_const

.. autofunction:: fraction

.. module:: sympy.simplify.ratsimp

.. autofunction:: ratsimp

.. autofunction:: ratsimpmodprime

.. module:: sympy.simplify.trigsimp

.. autofunction:: trigsimp

.. module:: sympy.simplify.powsimp

.. autofunction:: powsimp

.. autofunction:: powdenest

.. module:: sympy.simplify.combsimp

.. autofunction:: combsimp

.. module:: sympy.simplify.sqrtdenest

.. autofunction:: sqrtdenest

.. module:: sympy.simplify.cse_main

.. autofunction:: cse

.. autofunction:: sympy.simplify.cse_main::opt_cse

.. autofunction:: sympy.simplify.cse_main::tree_cse

.. module:: sympy.simplify.hyperexpand

.. autofunction:: hyperexpand

.. module:: sympy.simplify.epathtools

.. autoclass:: EPath
   :members:

.. autofunction:: epath
